@@ -1,17 +1,16 @@
 package POSIX::RT::MQ;
 
-# $Id: MQ.pm,v 1.12 2003/01/28 07:10:03 ilja Exp $
+# $Id: MQ.pm,v 1.6 2003/01/23 09:01:22 ilja Exp $
 
 use 5.006;
 use strict;
 use warnings;
 use Carp 'croak';
-use Fcntl 'O_NONBLOCK';
 
 require DynaLoader;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '0.04_04';
+our $VERSION = '0.01';
 
 bootstrap POSIX::RT::MQ $VERSION;
 
@@ -23,9 +22,6 @@ sub open
 
     my @args = @_;
     $args[2] = 0666                 unless defined $args[2];
-    # work around 'using undefined value' warnings
-    # todo: fix XS?
-    delete $args[3] unless defined $args[3];
     $args[3] = attr_pack($args[3])  if     defined $args[3]; # pack attr
     
     defined(my $mqdes  = mq_open(@args))  or return undef;
@@ -35,7 +31,7 @@ sub open
     # get attributes and save for future references (in receive())
     $self->{_saved_attr_} = $self->attr  or return undef;
     
-    return $self;
+    $self;
 }
 
 sub unlink 
@@ -68,7 +64,7 @@ sub send
 { 
     my $self = shift;
     (@_ >= 1 && @_ <= 2) or croak 'Usage: $mq->send($msg ,[ $prio ])';
-    return mq_send( $self->{mqdes}, $_[0], ($_[1] || 0) );
+    mq_send( $self->{mqdes}, $_[0], ($_[1] || 0) ) ;
 }
 
 sub receive 
@@ -79,46 +75,15 @@ sub receive
     wantarray ? @result : $result[0];
 }
 
-sub notify
-{ 
-    my $self = shift;
-    (@_ <= 1) or croak 'Usage: $mq->notify([ $signo ])';
-    mq_notify( $self->{mqdes}, @_ );
-}
-
-sub blocking
-{
-    my $self = shift;
-    (@_ <= 1) or croak 'Usage: $mq->blocking([ BOOL ])';
-
-    my $a = $self->attr()  or return undef;
-    my $old_blocking = ($a->{mq_flags} & O_NONBLOCK) ? 0 : 1;
-    if (@_) 
-    {
-        if ($_[0]) { $a->{mq_flags} &= (~O_NONBLOCK); }
-        else       { $a->{mq_flags} |= O_NONBLOCK;    }
-
-        $self->attr($a) or $old_blocking = undef;;
-    }
-
-    $old_blocking;
-}
-
 sub name { $_[0]->{name} }
 
-# expose mqdes
-sub mqdes { $_[0]->{mqdes} }
-
-sub DESTROY
+sub DESTROY 
 { 
     my $self  = shift;
-    #print "destrsroying $self\n";
     defined($self->{mqdes}) and mq_close($self->{mqdes});
     $self->{mqdes} = undef;
 }    
 
-# allow explicit close
-*close = \&DESTROY;
 
 sub attr_pack
 {
@@ -146,14 +111,14 @@ POSIX::RT::MQ - Perl interface for POSIX Message Queues
 =head1 SYNOPSIS
 
  use POSIX::RT::MQ;
-
+ 
  my $mqname = '/some_queue';
-
+ 
  my $attr = { mq_maxmsg  => 1024, mq_msgsize =>  256 };
 
  my $mq = POSIX::RT::MQ->open($mqname, O_RDWR|O_CREAT, 0600, $attr) 
      or die "cannot open $mqname: $!\n";
-
+ 
  $mq->send('some_message', 0) or die "cannot send: $!\n";
 
  my ($msg,  $prio)  = $mq->receive or die "cannot receive: $!\n";
@@ -180,7 +145,7 @@ A wrapper for the C<mq_open()> function.
 
  $mq = open('/some_q1', O_RDWR);
  $mq = open('/some_q2', O_RDWR|O_CREAT, 0600);
-
+ 
  $attr = { mq_maxmsg=>1000, mq_msgsize=>2048 };
  $mq = open('/some_q3', O_RDWR|O_CREAT, 0600, $attr);
 
@@ -235,7 +200,7 @@ A wrapper for the C<mq_getattr()> and C<mq_setattr()> functions.
 
  $current_attr = $mq->attr();
  $old_attr = $mq->attr($new_attr);
-
+ 
  # set the non-blocking mode:
  $attr = $mq->attr();
  $attr->{mq_flags} |= O_NONBLOCK;
@@ -264,8 +229,6 @@ pairs listed above.
 
 On error returns C<undef>.
 
-See also the description of C<blocking()> method.
-
 =item receive
 
 A wrapper for the C<mq_receive()> function.
@@ -308,102 +271,24 @@ functional (but 'anonymous') until closed by all current users. Also,
 subsequent calls to C<$mq-E<gt>name> will return C<undef> if C<$mq-E<gt>unlink>
 completes successfully.
 
-On errror returns C<undef>.
-
-=item notify([ $signo ])
-
-A limited wrapper for the C<mq_notify()> function.
-
-    my $got_usr1 = 0;
-    local $SIG{USR1} = sub { $got_usr1 = 1 };
-    $mq->notify(SIGUSR1)  or  warn "cannot notify(SIGUSR1): $!\n";
-
-If called with an argument C<$signo> this method registers the calling process
-to be notified of message arrival at an empty message queue in question.
-At any time, only one process may be registered for notification by a specific
-message queue. 
-
-If called without arguments and the process is currently registered for notification 
-by the message queue in question, the existing registration is removed.
-
-Return true on success, C<undef> on error.
-
-Currently this module dosn't support the full C<mq_notify()> semantic and doesn't
-let the user to provide his own C<struct sigevent>.
-
-The semantic of C<$mq-E<gt>notify($signo)> is equivalent in C to:
-
-        struct sigevent sigev;
-        sigev.sigev_notify = SIGEV_SIGNAL;
-        sigev.sigev_signo  = $signo
-        sigev.sigev_value.sival_int = 0;
-        mq_notify(mqdes, &sigev);
-
-The semantic of C<$mq-E<gt>notify()> is equivalent in C to:
-
-        mq_notify(mqdes, NULL);
-
-Please refer to documents listed in L</SEE ALSO> for a complete description of notifications.
-
-=item blocking([ BOOL ])
-
-A convenience method.
-
- $mq->blocking(0);
- # now in non-blocking mode
- ...
- $mq->blocking(1);
- # now in blocking mode
-
-If called with an argument C<blocking()> will turn on non-blocking behavior of
-the message queue in question if C<BOOL> is false, and turn it off if C<BOOL> is true.
-
-C<blocking()> will return the value of the previous setting, or the current setting 
-if C<BOOL> is not given.
-
-On errror returns C<undef>.
-
-You may get the same results by using the C<attr()> method.
-
 =item name
 
-A convenience method.
-
  $name = $mq->name();
 
 Returns either the queue name as it was supplied to C<open()>
 or C<undef> if C<$mq-E<gt>unlink> was (successfully) called before.
 
-=item name
-
- $fd = $mq->mqdes();
-
-Returns the message queue descriptor. On some operating systems (Linux, FreeBSD) the
-message queue descriptor is a regular file descripter that can be used with select / poll / etc.
-
 =back
 
-=head1 CONSTANTS
-
-=over 4
-
-=item MQ_OPEN_MAX
-
-Access to the MQ_OPEN_MAX constant.
-
- $open_max = POSIX::RT::MQ::MQ_OPEN_MAX;     
-
-=item MQ_PRIO_MAX
-
-Access to the MQ_PRIO_MAX constant.
-
- $prio_max = POSIX::RT::MQ::MQ_PRIO_MAX;     
-
-=back
 
 =head1 BUGS
 
-C<mq_notify()> function is not fully supported.
+C<mq_notify()> function is not yet supported.
+
+
+=head1 AUTHOR
+
+Ilja Tabachnik E<lt>billy@arnis-bsl.comE<gt>
 
 =head1 SEE ALSO
 
@@ -415,20 +300,4 @@ The Single UNIX Specification, Version 3 (http://www.unix.org/version3/)
 
 The Base Definitions volume of IEEE Std 1003.1-2001.
 
-=head1 AUTHORS
-
-Ilja Tabachnik E<lt>billy@arnis-bsl.comE<gt>
-(Original author)
-
-Wieger Opmeer E<lt>wiegerop@cpan.orgE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2003, Ilja Tabachnik
-
-Copyright (C) 2019, Wieger Opmeer
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
